# -*- coding: utf-8 -*-

from rest_framework import exceptions, viewsets
from rest_framework.decorators import action

from thx.api.views import ThuxViewMixin
from . import serializers
from ... import models


# LANGUAGE
class LanguageViewSet(ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Language.objects.all()
    serializer_class = serializers.LanguageSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_ and profile == '':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_ and profile == '':
            if self.action in [
                'list', 'retrieve', 'create', 'partial_update', 'destroy', 'enable', 'disable',
            ]:
                return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Language{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)
