# -*- coding: utf-8 -*-

from django.core.exceptions import PermissionDenied
from django.db import models
from django.utils.translation import ugettext_lazy as _


from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


class Language(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        primary_key=True,
        max_length=2,
        verbose_name=_('iso code language'),
    )
    name = models.CharField(
        max_length=20,
        verbose_name=_('name'),
    )
    country = models.CharField(
        max_length=20,
        verbose_name=_('country'),
    )
    nationality = models.CharField(
        max_length=20,
        verbose_name=_('nationality'),
    )

    class Meta:
        verbose_name = _('language')
        verbose_name_plural = _('languages')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_language", "Can list language"),
            ("detail_language", "Can detail language"),
            ("enable_language", "Can enable language"),
            ("disable_language", "Can disable language"),
        )

    def __str__(self):
        return self.name
